@@ -1,9 +1,6 @@
 """Abstraction layer to construct a workflow node using and airflow operator."""
 from collections.abc import Iterable
-from typing import List
-from typing import Tuple
 from typing import Type
-from typing import Union
 
 from airflow.operators.bash import BashOperator
 
@@ -11,7 +8,7 @@ from dkist_processing_core.task import TaskBase
 
 
 task_type_hint = Type[TaskBase]
-upstreams_type_hint = Union[List[Type[TaskBase]], None, Type[TaskBase]]
+upstreams_type_hint = list[task_type_hint] | task_type_hint | None
 
 
 class Node:
@@ -72,7 +69,7 @@ class Node:
 """
 
     @property
-    def dependencies(self) -> List[Tuple[str, str]]:
+    def dependencies(self) -> list[tuple[str, str]]:
         """List of upstream, downstream task name tuples."""
         return [(upstream.__name__, self.task.__name__) for upstream in self.upstreams]
 
