@@ -8,10 +8,8 @@ import json
 import logging
 from abc import ABC
 from abc import abstractmethod
-from collections import defaultdict
 from contextlib import contextmanager
 from os import environ
-from typing import Optional
 
 import elasticapm
 
@@ -29,7 +27,7 @@ class ApmTransaction:
     """
 
     @property
-    def _apm_server_url(self) -> Optional[str]:
+    def _apm_server_url(self) -> str | None:
         # Environment variable indicating how to connect to dependencies on the service mesh
         raw_mesh_config = environ.get("MESH_CONFIG", default="null")
         mesh_config = json.loads(raw_mesh_config)
@@ -59,7 +57,7 @@ class ApmTransaction:
         return json.loads(value)
 
     @property
-    def _apm_config(self) -> Optional[dict]:
+    def _apm_config(self) -> dict | None:
         if not self._apm_is_active:
             return None
         apm_client_config = {
