@@ -1,19 +1,15 @@
 """Global test fixtures."""
-from configparser import ConfigParser
 from contextlib import contextmanager
 from pathlib import Path
 from shutil import rmtree
 from typing import Any
-from typing import List
-from typing import Tuple
-from typing import Type
 
 import pytest
 
-import dkist_processing_core
 from dkist_processing_core import TaskBase
 from dkist_processing_core import Workflow
 from dkist_processing_core._node import Node
+from dkist_processing_core._node import task_type_hint
 from dkist_processing_core.tests.task_example import Task
 
 
@@ -90,7 +86,7 @@ def workflow():
 
 
 @pytest.fixture()
-def workflow_tasks(task_subclass) -> List[Type[TaskBase]]:
+def workflow_tasks(task_subclass) -> list[task_type_hint]:
     """List of Tasks that can be composed into a workflow."""
 
     class TaskA(task_subclass):
@@ -109,7 +105,7 @@ def workflow_tasks(task_subclass) -> List[Type[TaskBase]]:
 
 
 @pytest.fixture(params=["0_upstream", "1_upstream", "2_upstream"])
-def node(workflow_tasks, request) -> Tuple[Node, Type[TaskBase], Any, str, str]:
+def node(workflow_tasks, request) -> tuple[Node, task_type_hint, Any, str, str]:
     """Node instance and its component parts."""
     version = "V6-123"
     name = f"{request.param}_{version}"
