@@ -7,7 +7,15 @@ def test_workflow_export(workflow_tasks, workflow, export_path):
     When: Exporting the dag.
     Then: The exported dag compiles.
     """
-    workflow_instance, category, name, version, _ = workflow
+    (
+        workflow_instance,
+        input_data,
+        output_data,
+        category,
+        detail,
+        version,
+        tags,
+    ) = workflow
     TaskA, TaskB, TaskC, TaskD = workflow_tasks
     task_definitions = {
         TaskA: None,  # none
@@ -22,5 +30,9 @@ def test_workflow_export(workflow_tasks, workflow, export_path):
     dag_file = workflow_instance.export(export_path)
     # Then
     with dag_file.open(mode="r") as f:
-        compile(f.read(), filename=f"{category}_{name}_{version}.pyc", mode="exec")
+        compile(
+            f.read(),
+            filename=f"{input_data}_to_{output_data}_{category}_{detail}_{version}.pyc",
+            mode="exec",
+        )
     assert True  # exception not raised from compile
