@@ -9,7 +9,12 @@ from dkist_processing_core.tests.task_example import Task4
 # Task ->|               |----> Task4
 #        |---> Task3 --->|
 
-example = Workflow(process_category="valid", process_name="workflow", workflow_package=__package__)
+example = Workflow(
+    input_data="test-data",
+    output_data="valid",
+    category="core",
+    workflow_package=__package__,
+)
 example.add_node(task=Task, upstreams=None)
 example.add_node(task=Task2, upstreams=Task)
 example.add_node(task=Task3, upstreams=Task)
