@@ -2,5 +2,8 @@
 from dkist_processing_core import Workflow
 
 zero_node_workflow = Workflow(
-    process_category="invalid", process_name="zero_node_workflow", workflow_package=__package__
+    input_data="test-data",
+    output_data="zero-node",
+    category="core",
+    workflow_package=__package__,
 )
